@@ -57,6 +57,8 @@ __authors__  = (
     'Jason Normore',
     'Hoje Lee',
     'Adam Thalhammer',
+    'Georg Jähnig',
+    'Ralf Haring',
 )
 
 __license__ = 'Public Domain'
